:mod:`oasis`.DruckSampler
================================

.. currentmodule:: oasis

.. autoclass:: DruckSampler

   
   .. automethod:: __init__
   

.. Not needed since there is no "Examples" section in the docstrings
.. .. include:: oasis.DruckSampler.examples

.. raw:: html

    <div class="clearer"></div>